@@ -1,9 +1,10 @@
 from __future__ import annotations
 
 from workflows.file_task import FileTask
+from workflows.file_task import floor_datetime
 from workflows.task import Task
 
 
-__all__ = ["FileTask", "Task"]
-__version__ = "0.1.17"
+__all__ = ["FileTask", "floor_datetime", "Task"]
+__version__ = "0.1.18"
 _ = FileTask.run  # dead: disable
